pub struct QueueClient { /* private fields */ }Implementations
Sourceimpl QueueClient
impl QueueClient
Sourcepub fn create(&self) -> CreateQueueBuilder
pub fn create(&self) -> CreateQueueBuilder
Creates the queue.
Sourcepub fn delete(&self) -> DeleteQueueBuilder
pub fn delete(&self) -> DeleteQueueBuilder
Deletes the queue.
Sourcepub fn set_metadata(&self, metadata: Metadata) -> SetQueueMetadataBuilder
pub fn set_metadata(&self, metadata: Metadata) -> SetQueueMetadataBuilder
Sets or clears the queue metadata.
Keep in mind that keys present on Azure but not included in the passed
metadata parameter will be deleted. If you want to keep the preexisting
key-value pairs, retrieve them with GetMetadata first and then
update/add to the received Metadata struct. Then pass the Metadata back
to SetQueueMetadata. If you just want to clear the metadata, just pass
an empty Metadata struct.
Sourcepub fn get_metadata(&self) -> GetQueueMetadataBuilder
pub fn get_metadata(&self) -> GetQueueMetadataBuilder
Get the queue metadata.
Sourcepub fn get_acl(&self) -> GetQueueACLBuilder
pub fn get_acl(&self) -> GetQueueACLBuilder
Get the queue ACL.
This call returns all the stored access policies associated to the current queue.
Sourcepub fn set_acl(
&self,
policies: Vec<QueueStoredAccessPolicy>,
) -> SetQueueACLBuilder
pub fn set_acl( &self, policies: Vec<QueueStoredAccessPolicy>, ) -> SetQueueACLBuilder
Set the queue ACL.
You can call this function to change or remove already existing stored
access policies by modifying the list returned by get_acl.
While this SDK does not enforce any limit, keep in mind Azure supports a limited number of stored access policies for each queue. More info here https://docs.microsoft.com/rest/api/storageservices/set-queue-acl#remarks.
Sourcepub fn put_message<S: Into<String>>(&self, message: S) -> PutMessageBuilder
pub fn put_message<S: Into<String>>(&self, message: S) -> PutMessageBuilder
Puts a message in the queue.
Sourcepub fn peek_messages(&self) -> PeekMessagesBuilder
pub fn peek_messages(&self) -> PeekMessagesBuilder
Peeks, without removing, one or more messages.
Sourcepub fn get_messages(&self) -> GetMessagesBuilder
pub fn get_messages(&self) -> GetMessagesBuilder
Gets, shadowing them, one or more messages.
Sourcepub fn clear_messages(&self) -> ClearMessagesBuilder
pub fn clear_messages(&self) -> ClearMessagesBuilder
Removes all messages from the queue.
Sourcepub fn pop_receipt_client(
&self,
pop_receipt: impl Into<PopReceipt>,
) -> PopReceiptClient
pub fn pop_receipt_client( &self, pop_receipt: impl Into<PopReceipt>, ) -> PopReceiptClient
Turn into a PopReceiptClient.
pub fn queue_name(&self) -> &str
pub fn url(&self) -> Result<Url>